$.jqplot.LineRenderer

The default line renderer for jqPlot, this class has no options beyond the Series class. Draws series as a line.

Summary

$.jqplot.LineRenderer | The default line renderer for jqPlot, this class has no options beyond the Series class.
Properties |
smooth | True to draw a smoothed (interpolated) line through the data points with automatically computed number of smoothing points.
constrainSmoothing | True to use a more accurate smoothing algorithm that will not overshoot any data points.
bandData | Data used to draw error bands or confidence intervals above/below a line.
bands | Banding around line, e.g error bands or confidence intervals.
show | true to show the bands.
color | color of lines at top and bottom of bands [default: series color].
showLines | True to show lines at top and bottom of bands [default: false].
fill | True to fill area between bands [default: true].
fillColor | css color spec for filled area.
interval | User specified interval above and below line for bands [default: ‘3%’’].
Properties |
highlightMouseOver | True to highlight area on a filled plot when moused over.
highlightMouseDown | True to highlight when a mouse button is pressed over an area on a filled plot.
highlightColor | color to use when highlighting an area on a filled plot.

### Properties

### smooth

> this.renderer.smooth = false

True to draw a smoothed (interpolated) line through the data points with automatically computed number of smoothing points. Set to an integer number > 2 to specify number of smoothing points to use between each data point.

### constrainSmoothing

> this.renderer.constrainSmoothing = true

True to use a more accurate smoothing algorithm that will not overshoot any data points. False to allow overshoot but produce a smoother looking line.

### bandData

> this.renderer.bandData = []

Data used to draw error bands or confidence intervals above/below a line.

bandData can be input in 3 forms. jqPlot will figure out which is the low band line and which is the high band line for all forms:

A 2 dimensional array like [[yl1, yl2, ...], [yu1, yu2, ...]] where [yl1, yl2, ...] are y values of the lower line and [yu1, yu2, ...] are y values of the upper line. In this case there must be the same number of y data points as data points in the series and the bands will inherit the x values of the series.

A 2 dimensional array like [[[xl1, yl1], [xl2, yl2], ...], [[xh1, yh1], [xh2, yh2], ...]] where [xl1, yl1] are x,y data points for the lower line and [xh1, yh1] are x,y data points for the high line. x values do not have to correspond to the x values of the series and can be of any arbitrary length.

Can be of form [[yl1, yu1], [yl2, yu2], [yl3, yu3], ...] where there must be 3 or more arrays and there must be the same number of arrays as there are data points in the series. In this case, [yl1, yu1] specifies the lower and upper y values for the 1st data point and so on. The bands will inherit the x values from the series.

### bands

Banding around line, e.g error bands or confidence intervals.

### show

true to show the bands. If bandData or interval is supplied, show will be set to true by default.

### color

color of lines at top and bottom of bands [default: series color].

### showLines

True to show lines at top and bottom of bands [default: false].

### fill

True to fill area between bands [default: true].

### fillColor

css color spec for filled area. [default: series color].

### interval

> interval: '3%' }

User specified interval above and below line for bands [default: ‘3%’’]. Can be a value like 3 or a string like ‘3%’ or an upper/lower array like [1, -2] or [‘2%’, ‘-1.5%’]

### Properties

### highlightMouseOver

> this.highlightMouseOver = true

True to highlight area on a filled plot when moused over. This must be false to enable highlightMouseDown to highlight when clicking on an area on a filled plot.

### highlightMouseDown

> this.highlightMouseDown = false

True to highlight when a mouse button is pressed over an area on a filled plot. This will be disabled if highlightMouseOver is true.

### highlightColor

> this.highlightColor = null

color to use when highlighting an area on a filled plot.

An individual data series object.

> this.renderer.smooth = false

True to draw a smoothed (interpolated) line through the data points with automatically computed number of smoothing points.

> this.renderer.constrainSmoothing = true

True to use a more accurate smoothing algorithm that will not overshoot any data points.

> this.renderer.bandData = []

Data used to draw error bands or confidence intervals above/below a line.

> interval: '3%' }

User specified interval above and below line for bands [default: ‘3%’’].

> this.highlightMouseOver = true

True to highlight area on a filled plot when moused over.

> this.highlightMouseDown = false

True to highlight when a mouse button is pressed over an area on a filled plot.

> this.highlightColor = null

color to use when highlighting an area on a filled plot.
Close